==> icingaweb2-module-businessprocess_2.3.0.orig.tar.xz: icingaweb2-module-businessprocess-2.3.0/test/php/library/Businessprocess/ServiceNodeTest.php <==
<?php

namespace Tests\Icinga\Module\Businessprocess;

use Icinga\Module\Businessprocess\BpConfig;
use Icinga\Module\Businessprocess\ServiceNode;
use Icinga\Module\Businessprocess\Test\BaseTestCase;

class ServiceNodeTest extends BaseTestCase
{
    public function testReturnsCorrectHostName()
    {
        $this->assertEquals(
            'localhost',
            $this->pingOnLocalhost()->getHostname()
        );
    }

    public function testReturnsCorrectServiceDescription()
    {
        $this->assertEquals(
            'ping <> pong',
            $this->pingOnLocalhost()->getServiceDescription()
        );
    }

    public function testReturnsCorrectAlias()
    {
        $this->assertEquals(
            'localhost: ping <> pong',
            $this->pingOnLocalhost()->getAlias()
        );
    }

    public function testRendersCorrectLink()
    {
        $this->assertEquals(
            '<a href="/icingaweb2/businessprocess/service/show?host=localhost&amp;service=ping%20%3C%3E%20pong">'
            . 'localhost: ping &lt;&gt; pong</a>',
            $this->pingOnLocalhost()->getLink()->render()
        );
    }

    /**
     * @return ServiceNode
     */
    protected function pingOnLocalhost()
    {
        $bp = new BpConfig();
        return (new ServiceNode((object) array(
            'hostname' => 'localhost',
            'service'  => 'ping <> pong',
            'state'    => 0,
        )))->setBpConfig($bp)->setHostAlias('localhost')->setAlias('ping <> pong');
    }
}

==> icingaweb2-module-businessprocess_2.5.1.orig.tar.xz: icingaweb2-module-businessprocess-2.5.1/test/php/library/Businessprocess/ServiceNodeTest.php <==
<?php

namespace Tests\Icinga\Module\Businessprocess;

use Icinga\Module\Businessprocess\BpConfig;
use Icinga\Module\Businessprocess\ServiceNode;
use Icinga\Module\Businessprocess\Test\BaseTestCase;

class ServiceNodeTest extends BaseTestCase
{
    public function testReturnsCorrectHostName()
    {
        $this->assertEquals(
            'localhost',
            $this->pingOnLocalhost()->getHostname()
        );
    }

    public function testReturnsCorrectServiceDescription()
    {
        $this->assertEquals(
            'ping <> pong',
            $this->pingOnLocalhost()->getServiceDescription()
        );
    }

    public function testReturnsCorrectAlias()
    {
        $this->assertEquals(
            'ping <> pong on localhost',
            $this->pingOnLocalhost()->getAlias()
        );
    }

    public function testRendersCorrectLink()
    {
        $this->assertEquals(
            '<a href="/icingaweb2/businessprocess/service/show?host=localhost&amp;service=ping%20%3C%3E%20pong">'
            . 'ping &lt;&gt; pong on localhost</a>',
            $this->pingOnLocalhost()->getLink()->render()
        );
    }

    /**
     * @return ServiceNode
     */
    protected function pingOnLocalhost()
    {
        $bp = new BpConfig();
        return (new ServiceNode((object) array(
            'hostname' => 'localhost',
            'service'  => 'ping <> pong',
            'state'    => 0,
        )))->setBpConfig($bp)->setHostAlias('localhost')->setAlias('ping <> pong');
    }
}
